<?php

/**
 * @file
 * Contains namespace Drupal\Core\State\State.
 */

namespace Drupal\Core\State;

/**
 * Provides the state system using a key value store.
 */
class State implements StateInterface {

  /**
   * {@inheritdoc}
   */
  public function __construct() {
    ctools_include('object-cache');
  }

  /**
   * {@inheritdoc}
   */
  public function get($key, $default = NULL) {
    // We need to set the sid, or calls from drush, without a sid, will not
    // match calls from the browser.
    $result = ctools_object_cache_get('oauth2_token_manager_stage', $key, FALSE, 'sid');
    return is_null($result) ? $default : $result;
  }

  /**
   * {@inheritdoc}
   */
  public function getMultiple(array $keys) {
    foreach ($keys as $key) {
      $values[$key] = $this->get($key);
    }

    return $values;
  }

  /**
   * {@inheritdoc}
   */
  public function set($key, $value) {
    ctools_object_cache_set('oauth2_token_manager_stage', $key, $value, 'sid');
  }

  /**
   * {@inheritdoc}
   */
  public function setMultiple(array $data) {
    foreach ($data as $key => $value) {
      $this->set($key, $value);
    }
  }

  /**
   * {@inheritdoc}
   */
  public function delete($key) {
    ctools_object_cache_clear('oauth2_token_manager_stage', $key);
  }

  /**
   * {@inheritdoc}
   */
  public function deleteMultiple(array $keys) {
    foreach ($keys as $key) {
      $this->delete($key);
    }
  }

  /**
   * {@inheritdoc}
   */
  public function resetCache() {
    drupal_static_reset('ctools_object_cache_get');
  }

}
